@@ -7,18 +7,15 @@ import re
 import ssl
 import threading
 import time
+from typing import Union
 
 import requests
-from playsound import playsound
-
-if os.name == 'nt':
-    import winsound
 
 ssl._create_default_https_context = ssl._create_unverified_context
 from termcolor import cprint
 from inspect import currentframe
 
-__version__ = '0.1.38'
+__version__ = '0.1.40'
 
 __info__ = {
     '2022/01/04: 0.1.18 加入 __info__。',
@@ -39,9 +36,10 @@ __info__ = {
     '2022/07/15: 0.1.35 binance_copy_bot() 改用 API方式',
     '2022/07/16: 0.1.36 加入 read_warrant_bible()',
     '2022/07/17: 0.1.37 加入 tredis'
+    '2022/08/01: 0.1.39 加入註解，把一些東西拆開來，以免每次mypylib都要載入一堆 module',
+    '2022/08/05: 0.1.40 繼續拆開一些東西 tredis'
 }
 
-_MYPYLIB_ROOT = os.path.abspath(os.path.dirname(__file__))
 
 request_headers = {
     'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36'
@@ -404,7 +402,6 @@ class timeIt:
 ########################
 from decimal import Decimal
 
-
 def get_current_price_tick_dec(price: Decimal, down=False):
     # print(f'get_current_price_tick: {price}')
     if down:
@@ -761,110 +758,45 @@ def build_dealer_downloader(date=datetime.datetime(year=2020, month=1, day=1), t
             os.unlink(dealer_csv_path + '_')
 
 
-from line_notify import LineNotify
 
+def get_trade_days(date_start: Union[str, datetime.datetime] = '2018-01-01',
+                   date_end: Union[str, datetime.datetime] = '2022-07-31') -> list:
+    date_start = date_start if isinstance(date_start, str) else date_start.strftime('%Y-%m-%d')
+    date_end = date_end if isinstance(date_end, str) else date_end.strftime('%Y-%m-%d')
 
-class tLineNotify(threading.Thread):
+    file_cache = f'trade_days_{date_start}_{date_end}.txt'
 
-    def __init__(self, token, name=None):
-        threading.Thread.__init__(self)
-        self.line_notify = LineNotify(token, name=name)
-        self.queue = queue.Queue()
-        self.start()
+    if os.path.isfile(file_cache):
+        with open(file_cache) as fp:
+            return json.load(fp)
 
-    def on(self):
-        self.line_notify.on()
+    from FinMind.data import DataLoader
+    # print(date_start, date_end)
 
-    def off(self):
-        self.line_notify.off()
+    dl = DataLoader()
+    stock_data = dl.taiwan_stock_daily(stock_id='2330', start_date=date_start, end_date=date_end)
+    days = stock_data['date']
+    # print(days)
+    list_days = []
+    for x in days:
+        list_days.append(x)
 
-    def format(self, message):
-        return self.line_notify.format(message=message)
+    with open(file_cache, 'w+') as fp:
+        json.dump(list_days, fp)
 
-    def send(self, message, image_path=None, sticker_id=None, package_id=None):
-        self.queue.put((message, image_path, sticker_id, package_id))
-
-    def run(self):
-        while True:
-            try:
-                (message, image_path, sticker_id, package_id) = self.queue.get(timeout=1)
-            except queue.Empty:
-                pass
-            else:
-                if message is None:
-                    break
-                self.line_notify.send(message=message, image_path=image_path, sticker_id=sticker_id, package_id=package_id)
-
-    def stop(self):
-        self.queue.put((None, None, None, None))
-
-
-class tplaysound(threading.Thread):
-
-    def __init__(self):
-        threading.Thread.__init__(self)
-
-        self.queue = queue.Queue()
-
-        self.sound_alert = f'{_MYPYLIB_ROOT}/../data/alert.wav'
-
-        self.start()
-
-    def play(self, filename=None):
-        self.play_file(filename=filename)
-
-    def play_file(self, filename=None):
-        if filename is None:
-            filename = self.sound_alert
-        command = ('play', filename)
-        self.queue.put(command)
-        # print(f'send command {command}')
-
-    def run(self):
-        while True:
-            try:
-                (cmd, arg) = self.queue.get(timeout=1)
-            except queue.Empty:
-                pass
-            else:
-                if cmd == 'stop':
-                    break
-
-                if cmd == 'play':
-                    # print('got Play')
-                    if os.name == 'nt':
-                        # print('NT play')
-                        winsound.PlaySound(arg, winsound.SND_FILENAME)
-                    else:
-                        # print('POSIX play')
-                        playsound(arg)
-
-    def stop(self):
-        self.queue.put(('stop', 'stop'))
+    return list_days
 
 
 if __name__ == '__main__':
     from time import sleep
 
     if True:
-        tline = tLineNotify(token='wZus5sTyCscdtmfvQRQpxYTaAdiXHb0OJpljUE1aDXb')
-        tline.send('測試')
-        tline.stop()
+        ret = get_trade_days()
+        print(ret)
+
+        exit(0)
+
 
-    if True:
-        tps = tplaysound()
-        index = 0
-        while True:
-            tps.play_file()
-            tps.play_file()
-            tps.play_file()
-            tps.play_file()
-            sleep(3)
-            index += 1
-            if index == 3:
-                break
-        tps.stop()
-        tps.join()
 
     if False:
         build_dealer_downloader()
