@@ -2,26 +2,38 @@ import redis
 import threading
 from loguru import logger
 import traceback
+from time import sleep
+
+
+class base_tredis_msg_sender:
+    def __init__(self, tredis=None):
+        self.tredis: Tredis = tredis
+
+    def redis_msg_sender(self, data):
+        print(f'This is what I got: {data}')
+        if self.tredis is not None and self.tredis.r is not None:
+            ret = self.tredis.r.get(str(data))
+            if ret is not None:
+                print(f'This is what I have found {ret} {type(ret)}')
+                return ret
+            else:
+                print(f'Cannot find {data} on server')
+        return None
 
 
 class Tredis(threading.Thread):
     default_port = 6379
     default_db = 0
 
-    class base_tredis_msg_sender:
-        def __init__(self):
-            self.tredis: Tredis = None
 
-        def redis_msg_sender(self, data):
-            print(f'This is what I got: {data}')
-            if self.tredis is not None and self.tredis.r is not None:
-                ret = self.tredis.r.get(data)
-                if ret is not None:
-                    print(f'This is what I have found {ret} {type(ret)}')
-                else:
-                    print(f'Cannot find {data} on server')
-
-    def __init__(self, server, port, db, password, channel, prefix, redis_msg_sender):
+    def __init__(self,
+                 server='localhost',
+                 port=6379,
+                 db=0,
+                 password='',
+                 channel='test',
+                 prefix='test',
+                 redis_msg_sender=base_tredis_msg_sender()):
         threading.Thread.__init__(self)
         self.server = server
         self.port = port
@@ -30,9 +42,11 @@ class Tredis(threading.Thread):
         self.channel = channel
         self.prefix = prefix
         self.redis_msg_sender = redis_msg_sender
+        self.redis_msg_sender.tredis = self
         self.r: redis.client.Redis = None
         self.str_thread_exit_magic = 'redis thread exit'
 
+
         self.start()
 
     def run(self):
@@ -62,14 +76,35 @@ class Tredis(threading.Thread):
                     else:
                         function_send = getattr(self.redis_msg_sender, 'redis_msg_sender', None)
                         if function_send is not None and callable(function_send):
+                            logger.info(f'function_send: {data}')
                             function_send(data)
                 except Exception as e:
                     traceback.print_exc()
                     logger.exception(f'\033[1;33mredis subscribe\n{message}\n{e}\033[0m')
         logger.info(f'redis thread: {self} stopped.')
 
+    @logger.catch()
     def stop(self):
         t = threading.current_thread()
         self.r.publish(self.channel, self.str_thread_exit_magic)
 
 
+
+if __name__ == '__main__':
+    logger.disable('mypylib.tredis')
+    tredis = Tredis()
+
+    tredis.r.publish('test', 'That is a pancil')
+
+    index = 0
+    while True:
+        sleep(1)
+        index += 1
+        if index == 10000000000:
+            break
+
+    tredis.stop()
+
+
+
+
